# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ImcRecalledMessage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ImcNoticeMessage_pb2 as ImcNoticeMessage__pb2
import Message_pb2 as Message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18ImcRecalledMessage.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x16ImcNoticeMessage.proto\x1a\rMessage.proto\"\x89\x01\n\x12ImcRecalledMessage\x12\x31\n\toriginMsg\x18\x01 \x01(\x0b\x32\x1e.AcFunDanmu.Im.Message.Message\x12@\n\tnoticeMsg\x18\x02 \x01(\x0b\x32-.AcFunDanmu.Im.Cloud.Message.ImcNoticeMessageb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ImcRecalledMessage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IMCRECALLEDMESSAGE._serialized_start=97
  _IMCRECALLEDMESSAGE._serialized_end=234
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SixinCustomPushType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19SixinCustomPushType.proto\x12\x1f\x41\x63\x46unDanmu.Im.Cloud.Data.Update*@\n\x13SixinCustomPushType\x12\x15\n\x11INVALID_PUSH_TYPE\x10\x00\x12\x12\n\x0eRELATION_EVENT\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SixinCustomPushType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SIXINCUSTOMPUSHTYPE._serialized_start=62
  _SIXINCUSTOMPUSHTYPE._serialized_end=126
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientStatisticalDataConfig.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ClientStatisticalDataConfig.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Config\"g\n\x1b\x43lientStatisticalDataConfig\x12\x1f\n\x17\x63mdDataReportSampleRate\x18\x01 \x01(\x01\x12\'\n\x1fnetworkFlowCostReportSampleRate\x18\x02 \x01(\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ClientStatisticalDataConfig_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLIENTSTATISTICALDATACONFIG._serialized_start=65
  _CLIENTSTATISTICALDATACONFIG._serialized_end=168
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: HandshakeRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16HandshakeRequest.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"6\n\x10HandshakeRequest\x12\x10\n\x08unknown1\x18\x01 \x01(\x05\x12\x10\n\x08unknown2\x18\x02 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'HandshakeRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HANDSHAKEREQUEST._serialized_start=47
  _HANDSHAKEREQUEST._serialized_end=101
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChatTarget.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatTargetType_pb2 as ChatTargetType__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x43hatTarget.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x14\x43hatTargetType.proto\"Y\n\nChatTarget\x12\x10\n\x08targetId\x18\x01 \x01(\t\x12\x39\n\ntargetType\x18\x02 \x01(\x0e\x32%.AcFunDanmu.Im.Message.ChatTargetTypeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ChatTarget_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHATTARGET._serialized_start=65
  _CHATTARGET._serialized_end=154
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Custom.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x43ustom.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\"\x19\n\x06\x43ustom\x12\x0f\n\x07payload\x18\x01 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Custom_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CUSTOM._serialized_start=45
  _CUSTOM._serialized_end=70
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientConfigGetResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ClientConfig_pb2 as ClientConfig__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x43lientConfigGetResponse.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Config\x1a\x12\x43lientConfig.proto\"j\n\x17\x43lientConfigGetResponse\x12\x0f\n\x07version\x18\x01 \x01(\r\x12>\n\x0c\x63lientConfig\x18\x02 \x01(\x0b\x32(.AcFunDanmu.Im.Cloud.Config.ClientConfigb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ClientConfigGetResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLIENTCONFIGGETRESPONSE._serialized_start=81
  _CLIENTCONFIGGETRESPONSE._serialized_end=187
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PublicGroupSearchResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import PublicGroupSearchInfo_pb2 as PublicGroupSearchInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fPublicGroupSearchResponse.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Search\x1a\x1bPublicGroupSearchInfo.proto\"g\n\x19PublicGroupSearchResponse\x12J\n\x0fpublicGroupInfo\x18\x01 \x03(\x0b\x32\x31.AcFunDanmu.Im.Cloud.Search.PublicGroupSearchInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PublicGroupSearchResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PUBLICGROUPSEARCHRESPONSE._serialized_start=92
  _PUBLICGROUPSEARCHRESPONSE._serialized_end=195
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MultiMediaMessage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Media_pb2 as Media__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17MultiMediaMessage.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x0bMedia.proto\"c\n\x11MultiMediaMessage\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x31\n\x05media\x18\x02 \x03(\x0b\x32\".AcFunDanmu.Im.Cloud.Message.Media\x12\r\n\x05\x65xtra\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'MultiMediaMessage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MULTIMEDIAMESSAGE._serialized_start=69
  _MULTIMEDIAMESSAGE._serialized_end=168
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UpdateVoiceCallExtraRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import CallParam_pb2 as CallParam__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!UpdateVoiceCallExtraRequest.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call\x1a\x0f\x43\x61llParam.proto\"k\n\x1bUpdateVoiceCallExtraRequest\x12\x0e\n\x06roomId\x18\x01 \x01(\t\x12<\n\tcallParam\x18\x02 \x01(\x0b\x32).AcFunDanmu.Im.Cloud.Voice.Call.CallParamb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'UpdateVoiceCallExtraRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _UPDATEVOICECALLEXTRAREQUEST._serialized_start=86
  _UPDATEVOICECALLEXTRAREQUEST._serialized_end=193
# @@protoc_insertion_point(module_scope)
